/*******************************************************************************
Name   : 1b_prepare_variables.do  

Task   : Harmonize the working dataset, create additional variables to get 
		 inequality measures, and aggregate at the yearly level.
		 
Input  : ${raw_data}/working_data_3dF_all.dta
		 ${raw_data}/edad_cuit.dta
		 ${raw_data}/db_gender.dta

Output : ${processed_data}/invariant_property_traits.dta
		 ${processed_data}/generic.dta
		 ${processed_data}/p99
		 ${processed_data}/p99_9
		 ${processed_data}/working_data_3dF_yearly.dta
*******************************************************************************/
	
	* Loading working data
	use "${raw_data}/working_data_3dF_all.dta", replace
	sort nro_cuenta periodo


/****************************************************
Dealing with categorical variables
****************************************************/

	* Categories of land use
	egen maxcat = max(categoria), by(nro_cuenta)
	drop categoria categoria_siempre
	gen categoria = cond(maxcat == 1, 1, 										///
					cond(maxcat == 2 | maxcat == 3, 2, 			   				///
					cond(maxcat == 5, 3, 										///
					cond(maxcat == 0, ., 4))))
				  
	lab def categoria 1 "Residential" 2 "Commercial" 3 "Industrial" 4 "Others"				  
	lab val categoria categoria
	
	* Location in 3dF
	replace localidad = "Ciudad Jardín"   if localidad == "Ciudad Jardin Lomas del Palomar"
	replace localidad = "José Ingenieros" if localidad == "JosÃÂ© Ingenieros"
	replace localidad = "Martín Coronado" if localidad == "MartÃÂ­n Coronado"
	replace localidad = "Pablo Podestá"   if localidad == "Pablo PodestÃÂ¡"
	replace localidad = "Sáenz Peña"      if localidad == "SÃÂ¡enz PeÃÂ±a"
	
	* Payment method (there are 2% of payments without any method associated)
	gen metodo_pago = .
	replace metodo_pago = cond(caja_are == 1 | caja_are == 2 | caja_are == 3 |	   ///
							  caja_are == 4 | caja_are == 5 | caja_are == 6 |      ///
						      caja_are == 7 | caja_are == 8 | caja_are == 70 |     ///
							  caja_are == 90 | caja_are == 80 | caja_are == 31 |   ///
						      caja_are == 65 | caja_are == 60 | caja_are == 9 |    ///
						      caja_are == 10 | caja_are == 11 | caja_are == 12 |   ///
						      caja_are == 13 | caja_are == 14 | caja_are == 15, 1, ///
					      cond(caja_are == 45 | caja_are == 75 | caja_are == 55, 2, ///
					      cond(caja_are == 40 | caja_are == 50 | caja_are == 85, 3, caja_are)))
	
	lab def metodo_pago 1 "Cash" 2 "Online" 3 "Automatic debit"
	lab val metodo_pago metodo_pago
	
	* Counting variables for payment methods to be aggregated at the yearly level
	gen pago_efectivo = cond(metodo_pago == 1 & pago_cuota == 1, 1, cond(!missing(metodo_pago), 0, .))
	lab def pago_efectivo 0 "Other" 1 "Payment with cash"
	lab val pago_efectivo pago_efectivo
	
	gen pago_online = cond(metodo_pago == 2 & pago_cuota == 1, 1, cond(!missing(metodo_pago), 0, .))
	lab def pago_online 0 "Other" 1 "Payment online"
	lab val pago_online pago_online
	
	gen pago_debito_autom = cond(metodo_pago == 3 & pago_cuota == 1, 1, cond(!missing(metodo_pago), 0, .)) 
	lab def pago_debito_autom 0 "Other" 1 "Automatic debit"
	lab val pago_debito_autom pago_debito_autom	
	
	gen pago_efectivo_share = monto_pago if (metodo_pago == 1 & pago_cuota == 1)
	gen pago_online_share   = monto_pago if (metodo_pago == 2 & pago_cuota == 1)
	gen pago_debito_share   = monto_pago if (metodo_pago == 3 & pago_cuota == 1)
	
	* Number of payments made in the year
	bys nro_cuenta anio: egen n_pagos = sum(pago_cuota)
	
	/*
	tab n_pagos
    n_pagos |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |  1,601,728       34.09       34.09
          1 |    175,034        3.73       37.82
          2 |    132,419        2.82       40.64
          3 |    196,702        4.19       44.83
          4 |     59,682        1.27       46.10
          5 |     62,701        1.33       47.43
          6 |     65,592        1.40       48.83
          7 |     66,762        1.42       50.25
          8 |     75,473        1.61       51.85
          9 |     80,394        1.71       53.57
         10 |    104,057        2.21       55.78
         11 |    172,621        3.67       59.46
         12 |  1,904,748       40.54      100.00
------------+-----------------------------------
      Total |  4,697,913      100.00
	*/
	
	* Always payers (1 if taxpayer made 12 payments a year, 0 otherwise)
	gen always_payer = (n_pagos == 12 | pago_anual_cuenta_anio == 1)
	
	* Never payers (1 if taxpater never made any payment, 0 otherwise)
	gen never_payer = (n_pagos == 0)
	
	* Payment made on time (up to 15 days after the due date)
	gen day   = day(fpago_are)
	gen month = month(fpago_are)
	tab day

	gen pay_timely=pago_cuota_mismo_mes
	replace pay_timely=0 if (day>27 & day!=. & month==cuota) 
	replace pay_timely = 1 if pago_anual_cuenta_anio == 1
	*replace pay_timely = 1 if (codadm == 49 & n_month == 7 & anio >= 2021)
	
	* Blocks and properties in capital city
	egen cuadra = group(num_cuadra)
	gen caseros = cond(localidad == "Caseros", 1, cond(missing(localidad), ., 0))
	
	
	
/****************************************************
Store time invariant traits
****************************************************/

	* Time invariant traits at the property level
	preserve
		duplicates drop nro_cuenta, force
		lab var caseros "Property located in Caseros"
		lab var metros_frente "Linear front meters"
		keep nro_cuenta arba metros_frente num_cuadra cuadra localidad lado calle numero codigo_postal caseros
		save "${processed_data}/invariant_property_traits.dta", replace
	restore



/****************************************************
Aggregate at the yearly level
****************************************************/	

	* Removing 2021 (only includes payments made in January)
	drop if anio == 2021
	
	* Collapsing data (Categorial variables changing throughout the year are excluded, like mean of payment)
	gcollapse (first) valuacion_3f arba categoria always_payer never_payer maxcat pago_anual_cuenta_anio    ///
			  (sum) monto_debito monto_pago pago_efectivo pago_cuota_mismo_mes pago_debito_autom pago_cuota ///
			        pay_timely pago_online pago_efectivo_share pago_debito_share pago_online_share	/// 
			  (mean) demora_pago, by(id2 id nro_cuenta anio)
			  
	replace demora_pago = round(demora_pago)
	rename arba valuacion_arba

	
	
/*****************************************************
G-Percentiles using the assessed value of the property
*****************************************************/		
	
			* 2 obs. in 2020 and 444 obs. in 2021 have no nro_cuenta. Let's create generic numbers for them,
			* so we can impute their place in the distribution. We can decide another startegy for these cases later.
			preserve
			keep if nro_cuenta == ""
				/* None of these cases are duplicates, so we can create unique generic numbers
				duplicates tag id2 anio, g(t)
				tab t
						  t |      Freq.     Percent        Cum.
				------------+-----------------------------------
						  0 |        446      100.00      100.00
				------------+-----------------------------------
					  Total |        446      100.00
				drop t	*/
			gen cta_generico = _n
			tostring cta_generico, replace
			keep id2 anio cta_generico
			save "${processed_data}/generic", replace
			restore
			
			merge 1:1 id2 anio using "${processed_data}/generic"
			g cuenta_generica = cond(_merge == 3, cta_generico, nro_cuenta)
			drop _merge cta_generico
	
	
	* --------------------- Now, let's build the whole distribution
	* decile		: gives yearly decile from 1-10
	* decile_top    : gives yearly decile from 1-10 with 10 split in 10.0, 10.2, 10.4, 10.6, 10.8
	* percentile    : gives yearly percentile from 1-99
	* percentile_top: gives yearly percentile from 1-99 with 99 split in 99.0, 99.1, 99.2, ..., 99.9
	
	* Distribution for residential properties only
	egen decile        = xtile(valuacion_3f) if categoria == 1, by(anio) nq(10) 
	egen percentile    = xtile(valuacion_3f) if categoria == 1, by(anio) p(1(1)99) 
	replace percentile = percentile-1
	
	* Top 10 for deciles
	preserve
		keep if decile >= 10 & categoria == 1
		egen top_ntile5 = xtile(valuacion_3f), by(anio) nq(5) 
		keep cuenta_generica top_ntile5 anio
		save "${processed_data}/p99", replace
	restore
	
	* Top 10 for percentiles
	preserve
		keep if percentile >= 99 & categoria == 1
		egen perc_99 = xtile(valuacion_3f), by(anio) nq(10) 
		keep cuenta_generica perc_99 anio
		save "${processed_data}/p99_9", replace
	restore
	
	* Merge with main dataset
	merge 1:1 cuenta_generica anio using "${processed_data}/p99" 
	bys anio: gen decile_top = cond(!missing(top_ntile5), decile+(top_ntile5-1)/10, decile)
	drop _merge
	
	merge 1:1 cuenta_generica anio using "${processed_data}/p99_9" 
	bys anio: gen percentile_top = cond(!missing(perc_99), percentile+(perc_99-1)/10, percentile)
	drop _merge perc_99 top_ntile5 cuenta_generica
	
	* Now we build the distribution including all property categories 
	egen decile_all 	   = xtile(valuacion_3f), by(anio) nq(10) 
	egen percentile_all    = xtile(valuacion_3f), by(anio) p(1(1)99) 
	replace percentile_all = percentile_all-1
	
	
	
/*****************************************************
Additional outcomes
*****************************************************/	

	* Identifying residential properties
	g residential = cond(categoria == 1, 1, 0)
	
	* At least one payment in the year paid on time (extensive margin)
	gen pay_on_time = cond(pay_timely >= 1, 1, 0)
	
	* Share of payments made on time out of the 12 bills due in a year (intensive margin)
	gen share_timely = (pay_timely / 12) * 100
	gen all_on_time  = (share_timely == 100)
	
	* Dummy for payment method (pay cash if 100% of bills were paid with cash, and so on)
	g cash   = pago_efectivo / pago_cuota
	g online = pago_online / pago_cuota
	g debit  = pago_debito_autom / pago_cuota
	
	gen pay_cash   = (cash == 1)
	gen pay_online = (online == 1)
	gen pay_debit  = (debit == 1)
	gen pay_mixed  = (cash != 1 & online != 1 & debit != 1)
	
	* Share of payments made online 
	gen share_pay_cash   = pago_efectivo_share / monto_pago
	gen share_pay_online = pago_online_share / monto_pago
	gen share_pay_debit  = pago_debito_share / monto_pago
	
	* Tax effectively paid as percentage of the due tax liability, trimmed to lie in [0, 1]
	g share_payment = (monto_pago / monto_debito) * 100
	replace share_payment = cond(share_payment < 0 & !missing(share_payment), 0, share_payment)
	replace share_payment = cond(share_payment > 100 & !missing(share_payment), 100, share_payment)

	* Difference between due payment and effectively paid bill
	g diff_payment = monto_debito - monto_pago
	
	* Effective tax rates
	g tasa_efectiva_pago = (monto_pago / valuacion_3f) * 100
	winsor2 tasa_efectiva_pago, cuts(1 99)
	replace tasa_efectiva_pago_w = round(tasa_efectiva_pago_w, 1)
	
	g tasa_efectiva_debito = (monto_debito / valuacion_3f) * 100
	winsor2 tasa_efectiva_debito, cuts(1 99)
	replace tasa_efectiva_debito_w = round(tasa_efectiva_debito_w, 1)
	
	* Identify age of owner using the two first two digits of the CUIT
	merge m:1 nro_cuenta using "${raw_data}/edad_cuit"
	drop if _merge == 2
	drop _merge 
	
	* Set to missing edad_cuit >= 90 because those are foreign citizens
	replace edad_cuit = . if edad_cuit >= 90
	
	* Ownership by gender
	merge m:1 nro_cuenta using "${raw_data}/db_gender.dta", gen(merge_gender) keepusing(female_cuit1 female_cuit2)
	drop if merge_gender == 2
	
	gen owner = .
	replace owner = 1 if female_cuit1 == 1 & female_cuit2 == .
	replace owner = 2 if female_cuit1 == 0 & female_cuit2 == .
	replace owner = 3 if female_cuit1 != . & female_cuit2 != .
	
	lab def owner 1 "Women" 2 "Men" 3 "Co-Owned"
	lab val owner owner

	drop female_cuit1 female_cuit2 merge_gender
	
	* Fraction of residential properties for which gender ownership is identified
	gen res_owner = cond(!missing(owner) & residential == 1, 1, 0)
	replace res_owner = . if residential == 0
	
	* Fraction of female- and co-owned residential properties
	gen fem_owner = (owner == 1 & residential == 1)
	replace fem_owner = . if residential == 0
	
	gen co_owner  = (owner == 3 & residential == 1)
	replace co_owner = . if residential == 0
	
	
/*****************************************************
Adding labels 
*****************************************************/	

	lab var id2 				   "Masked property account number"
	lab var id  				   "DNI number"
	lab var nro_cuenta 			   "Property account number"
	lab var anio 				   "Year"
	lab var maxcat 				   "Property category, max(categoria)"
	lab var pago_anual_cuenta_anio "Made annual payment (\%)"
	lab var valuacion_3f 		   "Assessed property value (AR\ $)"
	lab var valuacion_arba         "=1 if ARBA assessement, =0 otherwise"
	lab var categoria              "Property category, invariant"
	lab var always_payer 		    "Always payer" 								// "=1 if pays 12 times a year, =0 otherwise"
	lab var never_payer			   "Never payer"								// "=1 if zero payments in a year, =0 otherwise"
	lab var monto_debito 		   "Tax liability (AR\ $)"
	lab var monto_pago 			   "Tax liability, efectively paid (AR\ $)"
	lab var pago_efectivo 		   "# payments made with cash"
	lab var pago_cuota_mismo_mes   "Number of payments made in the same month"
	lab var pago_debito_autom 	   "# payments made with automatic debit"
	lab var pago_cuota			   "# payments made in a year"
	lab var pay_timely			   "# payments made up to 15 days after due date"
	lab var pago_online		       "# payments made online"
	lab var demora_pago 		   "Late payments in days"
	lab var decile 				   "Decile on residential property assessed value"
	lab var decile_all			   "Decile on property assessed value, all type of properties"
	lab var percentile 			   "Percentile on residential property assessed value"
	lab var percentile_all		   "Percentile on property assessed value, all type of properties"
	lab var decile_top 			   "Decile on residential property assessed value, top 10"
	lab var percentile_top 		   "Percentile on residential property assessed value, top 10"
	lab var pay_on_time			   "Paid on time"
	lab var residential            "Residential property"
	lab var share_payment		   "Payment to tax liablity ratio (\%)"	
	lab var tasa_efectiva_pago     "Empirical ETR (\%)"
	lab var tasa_efectiva_pago_w   "Effective tax rate, paid tax (winsor)"
	lab var tasa_efectiva_debito   "Statutory ETR (\%)"
	lab var tasa_efectiva_debito_w "Effective tax rate, tax liability (winsor)"
	lab var pay_online			   "=1 if 100% of bills paid online, =0 otherwise"
	lab var pay_cash 			   "=1 if 100% of bills paid cash, =0 otherwise"
	lab var pay_debit 			   "=1 if 100% of bills paid autom. debit, =0 otherwise"
	lab var pay_mixed 			   "=1 if use mixed methods to pay, =0 otherwise"
	lab var share_timely		   "# of bills (out od 12) paid on time"
	lab var all_on_time			   "=1 if 100% of bills paid on time, =0 otherwise"
	lab var diff_payment		   "Difference between due bill and payment"
	lab var share_pay_cash		   "Share of bills amounts paid with cash"
	lab var share_pay_online	   "Share of bills amounts paid online"
	lab var share_pay_debit		   "Share of bills amounts paid with autom. debit"
	lab var edad_cuit			   "Digits for age using CUIT number"
	lab var owner 				   "Type of ownership"
	lab var res_owner    		   "Residential properties with gender assigned"
	lab var fem_owner	 		   "Female-owned residential properties"
	lab var co_owner	 		   "Co-owned residential properties"
	
	duplicates drop nro_cuenta anio, force
	compress
	save "${processed_data}/working_data_3dF_yearly.dta", replace
		