/*******************************************************************************
Name   : 2a_analysis_tables.do

Task   : Create tables with summary statistics on property and gender.

Input  : ${processed_data}/working_data_3dF_yearly.dta
		 ${processed_data}/invariant_property_traits.dta
		 ${raw_data}/db_gender.dta
		 
Output : ${processed_data}/str.dta
		 statutory_tax_rates.tex
		 descriptive_property_year.tex
		 reg_payments.tex
*******************************************************************************/

/****************************************************
Tables using yearly aggregates
****************************************************/

	* Loading data
	use "${processed_data}/working_data_3dF_yearly.dta", clear
	sort nro_cuenta anio
	
	* Generate unit for counting properties
	gen  unit = 1
	
	* Removing properties without nro_cuenta
	drop if nro_cuenta == ""
	
	* Merge with time invariant characteristics
	merge m:1 nro_cuenta using "${processed_data}/invariant_property_traits.dta", keepusing(metros_frente num_cuadra localidad caseros cuadra)
	keep if _merge == 3
	drop _merge

	* Merge with gender data
	merge m:1 nro_cuenta using "${raw_data}/db_gender.dta", gen(merge_gender)
	drop if merge_gender == 2
	
	
/**************************************************************************
STATUTORY TAX RATES
**************************************************************************/
	
	* Statutory tax rates defined in the tax code (Ordenanza Impositiva)
	preserve
		keep maxcat
		drop if maxcat == 0
		duplicates drop maxcat, force
		gsort +maxcat
		
		gen str_2018 = .
		replace str_2018 = 0.3  if maxcat == 1
		replace str_2018 = 0.45 if maxcat == 2
		replace str_2018 = 0.7  if maxcat == 3
		replace str_2018 = 0.7  if maxcat == 4
		replace str_2018 = 0.7  if maxcat == 5
		replace str_2018 = 0.1  if maxcat == 6
		replace str_2018 = 0.1  if maxcat == 7
		replace str_2018 = 0.45 if maxcat == 8
		
		gen str_2019 = .
		replace str_2019 = 0.5  if maxcat == 1
		replace str_2019 = 0.75 if maxcat == 2
		replace str_2019 = 1.18 if maxcat == 3
		replace str_2019 = 1.27 if maxcat == 4
		replace str_2019 = 1.22 if maxcat == 5
		replace str_2019 = 0.17 if maxcat == 6
		replace str_2019 = 0.17 if maxcat == 7
		replace str_2019 = 0.76 if maxcat == 8
		
		gen str_2020 = .
		replace str_2020 = 0.69 if maxcat == 1
		replace str_2020 = 1.04 if maxcat == 2
		replace str_2020 = 1.68 if maxcat == 3
		replace str_2020 = 1.84 if maxcat == 4 
		replace str_2020 = 1.77 if maxcat == 5
		replace str_2020 = 0.24 if maxcat == 6 
		replace str_2020 = 0.24 if maxcat == 7 
		replace str_2020 = 1.10 if maxcat == 8
		
		save "${processed_data}/str.dta", replace
	restore
	
	* Number of properties for each category in 2018
	preserve
		keep if anio == 2018
		gcollapse (count) unit, by(maxcat)
		gsort +maxcat
		
		merge 1:1 maxcat using "${processed_data}/str.dta"
		
		qui sum unit, d
		gen share = (unit / `r(sum)') * 100
		format share str* %3.1f 
		
		order maxcat unit share str*
		drop _merge
		
		mkmat unit share str*, matrix(tasas)
		
		frmttable using "${tables}/statutory_tax_rates.tex", replace statmat(tasas) tex fr ///
				  rtitles("Residential"\ "Residential with commerce/factory"\"Commercial"\ ///
				  "Empty lot"\"Industrial"\"Civil entities"\"Religious entities"\ ///
				  "Wholesale establishments") ctitles("\textbf{Category}", "\underline{\textbf{N° Properties}}", "", ///
				  "\underline{\textbf{STR by year (\%)}}", "", "" \ "", "N", "\%", "2018" "2019" "2020") ///
				  multicol(1,2,2;1,4,3) sdec(0,1,2,2,2) hlines(10100000001)
	restore
	
	
/**************************************************************************	
 TABLE WITH SUMMARY STATISTICS  
**************************************************************************/

	* Globals
	global var_property residential caseros metros_frente res_owner fem_owner co_owner
	global var_tax      valuacion_3f monto_debito tasa_efectiva_debito tasa_efectiva_pago share_payment pay_on_time always_payer never_payer
	global var_unit     unit
	
	* PANEL A: Property characteristics
	eststo drop *
		foreach x of numlist 18 19 20 {
				eststo stats_`x': quietly estpost summarize $var_property if anio == (2000+`x'), d
		}
	
	esttab stats_*  using "${tables}/descriptive_property_year.tex",  ///
		   cells("mean(fmt(%12.2fc))") mtitles("2018" "2019" "2020") nonum ///
		   refcat(residential "\textbf{Panel A: Property Characteristics}" valuacion_3f ///
		   "\textbf{Panel B: Taxation and Payments}", nolabel) /// 
		   label replace f booktabs brackets gap noobs ///
		   starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)
		
	* PANEL B: Taxation and Payments
	eststo drop *
		foreach x of numlist 18 19 20 {
				eststo stats_`x': quietly estpost summarize $var_tax if anio == (2000+`x'), d
		}
	
	esttab stats_*  using "${tables}/descriptive_property_year.tex", append  ///
		   refcat(residential "\textbf{Panel A: Property Characteristics}" valuacion_3f ///
		   "\textbf{Panel B: Taxation and Payments}", nolabel) /// 
		  cells("mean(fmt(%12.2fc))" "sd(fmt(%12.2fc) par)")  ///
		  nonum noobs nomtitle collabels(none) ///
		  label f booktabs gap 
		  
	* Number of properties
	eststo drop *
		foreach x of numlist 18 19 20 {
				eststo stats_`x': quietly estpost summarize $var_unit if anio == (2000+`x'), d
		}
	
	esttab stats_* using "${tables}/descriptive_property_year.tex", append ///
		   cells("count(fmt(%12.0fc)) ") label booktabs nonum noobs nomtitle collabels(none) f  ///
		   coeflabels(unit "Number of properties" cuadra "Number of blocks") postfoot(\bottomrule)
	
	

/**************************************************************************
REGRESSIONS FOR PAYMENT METHODS
**************************************************************************/

	* Merge with gender data
	cap drop merge_gender
	merge m:1 nro_cuenta using "${raw_data}/db_gender.dta", gen(merge_gender)
	drop if merge_gender == 2
	
	* Remove accounts with lots of duplicates (mainly construction companies)
	keep if type_duplicates!=11 & type_duplicates!=12
	
	gen age_2 = edad_cuit^2
	
	* Running models
	eststo drop *
	foreach var of varlist pay_cash pay_online pay_mixed share_pay_online {
		
		eststo: reg `var' female_cuit1 if (residential == 1 & anio == 2018 & never_payer == 0), robust
		qui sum `var' if e(sample)
		estadd scalar mean_dv `r(mean)'
		estadd loc age 		 "No"
		estadd loc block_fe  "No"
		estadd loc decile_fe "No"
		
		eststo: reghdfe `var' female_cuit1 edad_cuit age_2 if (residential == 1 & anio == 2018 & never_payer == 0), a(num_cuadra decile) vce(robust)
		qui sum `var' if e(sample)
		estadd scalar mean_dv `r(mean)'
		estadd loc age 		 "Yes"
		estadd loc block_fe  "Yes"
		estadd loc decile_fe "Yes"
	}
	
	esttab using "${tables}/reg_payments.tex", replace booktabs f se(2) b(3) keep(female_cuit1 _cons) ///
		   coeflabels(female_cuit1 "$\mathbb{1}$(Female=1)" _cons "Constant") postfoot(\bottomrule) star(* 0.10 ** 0.05 *** 0.01) nomtitles ///
		   stats(N r2 mean_dv age block_fe decile_fe, labels(N R-Squared "Mean Dep Var 2018" "Control for age?" "Block FE?" "Value decile FE?") fmt(%12.0fc %12.2fc)) ///
		   mgroups("$\mathbb{P}$(Cash=1)" "$\mathbb{P}$(Online=1)" "$\mathbb{P}$(Mixed=1)" "Share Online", ///
	       span prefix(\multicolumn{@span}{c}{) suffix(}) pattern(1 0 1 0 1 0 1 0) erepeat(\cmidrule(lr){@span})) 	
	
	