
/*******************************************************************************
Name   : 2b_descriptives_figures.do

Task   : Create figures describing data on property taxes and gender.

Input  : ${raw_data}/db2_170224f.dta
		 ${raw_data}/db_gender.dta
		 ${processed_data}/working_data_3dF_yearly.dta
		 ${processed_data}/invariant_property_traits.dta
		 
Output : ${processed_data}/owed_2019
		 time_series_payment_owner.pdf
		 bar_taxes_gender.pdf
		 charges_deciles_2019.pdf
		 hist_assessed_value_2018.pdf
		 cdf_assessed_value_gender.pdf
		 etr_ownership.pdf
		 effective_tax_rate.pdf
		 prob_pay.pdf
		 prob_annual_payment_gender.pdf
		 residential_type_percentile.pdf
		 ownership_scatter_gender.pdf
*******************************************************************************/


/****************************************************
Stats using monthly aggregates
****************************************************/

* Payment rate across time
	use "${raw_data}/db2_170224f.dta", replace
	keep if anio >= 2018 & anio <= 2022
			
	tostring cuenta, replace
	gen nro_cuenta = cuenta + "/" + dv
	sort nro_cuenta anio
	
* Merge with gender data
	merge m:1 nro_cuenta using "${raw_data}/db_gender.dta", gen(merge_gender)
	drop if merge_gender == 2
	
* Merge with residential properties
	merge m:m nro_cuenta using "${processed_data}/working_data_3dF_yearly.dta", keepusing(residential owner decile percentile)
	drop if _merge == 2
	drop _merge 
	
* Remove accounts with lots of duplicates (mainly construction companies)
	keep if type_duplicates!=11 & type_duplicates!=12
	
* Additional outcomes 	
	gen pays = (pago_cuota >= 1 & !mi(pago_cuota))
	gen unit = 1
	
	gen day  = day(fpago)
	tab day
	
	tostring anio, gen(year)
	tostring cuota, gen(n_month)
	replace n_month = cond(length(n_month) == 1, "0"+n_month, n_month)
	
	gen period = year + n_month
	gen date = date(period, "YM")
	format date %td
	gen month = mofd(date)
	format month %tm
	destring n_month, replace
	
	gen anual = (tipo_cuota == 3)
	bys cuenta anio: egen pago_anual = max(anual)
	
	gen pay_timely=pago_cuota_mismo_mes
	replace pay_timely = 0 if (day>27 & day!=. & n_month==cuota)
	replace pay_timely = 1 if pago_anual == 1
	replace pay_timely = 1 if (codadm == 49 & anio >= 2021)
	
	
* Monthly time series for payments on time	
	preserve
		keep if residential == 1 & anio >= 2019
		gcollapse (mean) pay_timely, by(owner month)
		drop if mi(owner)
		reshape wide pay_timely, i(month) j(owner)
		
		twoway (scatter pay_timely1 month, c(l) msymbol(t) lc(dknavy%40) mc(dknavy%40)) 	    ///
			   (scatter pay_timely2 month, c(l) msymbol(X) lc(blue%60) mc(blue%60))  	///
			   (scatter pay_timely3 month, c(l) msymbol(o) lc(ebblue%70) mc(ebblue%70)),  ///
			   $graphopt xtitle("Billing Period") ylabel(0(.1)1, angle(0)) ///
			   subtitle("% paid on time", placement(7) span) ///
			   legend(row(3) lab(1 "Women") lab(2 "Men") lab(3 "Co-Owned") ring(0) pos(1)) ///
			   xscale(titlegap(3)) xlabel(#11, labsize(small)) 
		graph export "${figures}/time_series_payment_owner.pdf", replace
	restore
	
* Aggregates for tax gap
	preserve
		use "${processed_data}/working_data_3dF_yearly.dta", replace
		keep if anio == 2019 & residential == 1
		gcollapse (sum) monto_debito, by(owner)
		save "${processed_data}/owed_2019", replace
	restore
	
	preserve
		keep if (residential == 1 & anio == 2019 & pay_timely == 1)
		gcollapse (sum) importe_total_3, by(owner)
		
		merge 1:1 owner using "${processed_data}/owed_2019", keepusing(monto_debito)
		drop if _merge == 2
		drop _merge 
		drop if mi(owner)
		
		replace importe_total_3 = importe_total_3 / 1000000
		replace monto_debito = monto_debito / 1000000
		
		gen share = (importe_total_3 / monto_debito)*100
		gen gap = 100 - share
		
		qui sum gap if owner == 1
		loc women: di %4.1fc `r(mean)'
		qui sum gap if owner == 2
		loc men: di %4.1fc `r(mean)'
		qui sum gap if owner == 3
		loc co: di %4.1fc `r(mean)'
		
		graph bar monto_debito importe_total_3,  over(owner) $graphopt ylabel(0(50)300, angle(0)) 			   	    ///
			  bar(1, color(ebblue%70)) bar(2, color(gray%70)) blabel(bar, pos(outside) color(gray) format(%9.0fc))  ///
			  legend(row(2) order(1 "Total tax owed" 2 "Total tax paid") ring(0) pos(11))						    ///
			  subtitle("Million ARS", placement(7) span size(medsmall)) text(180 15 "Tax gap:`women'%", color(red)) ///
			  text(220 50 "Tax gap:`men'%", color(red)) text(250 85 "Tax gap:`co'%", color(red))
		graph export "${figures}/bar_taxes_gender.pdf", replace
	restore
	

* Share of fixed and variable charges in April 2019
	preserve
		keep if residential == 1
		keep if percentile >= 2 & anio == 2019
		keep if n_month==4
		
		gen cargos_fijos=167
		gen cargos_variables=0.005*(valuacion_arba/12)
		gen cuota_reconstruida=cargos_fijos+cargos_variables
		
		collapse (sum) cargos_fijos cargos_variables cuota_reconstruida, by(decile)
		
		graph bar cargos_fijos cargos_variables, over(decile) percent stack $graphopt 		 ///
		legend(row(1) order(1 "Fixed charge" 2 "Variable charge") pos(6)) ylabel(, angle(0)) ///
		bar(1, color(blue%50)) bar(2, color(dknavy%80)) b2title("Deciles (assessed value)")  ///
		ytitle("Proportion (%), 2019") blabel(bar, pos(center) color(white) format(%9.1fc))
		graph export "${figures}/charges_deciles_2019.pdf", replace
	restore
	
	
/****************************************************
Stats using yearly aggregates
****************************************************/

* Loading data
	use "${processed_data}/working_data_3dF_yearly.dta", clear
	sort nro_cuenta anio
	
* Generate unit for counting properties
	gen  unit = 1
	
* Merge with gender data
	merge m:1 nro_cuenta using "${raw_data}/db_gender.dta", gen(merge_gender)
	drop if merge_gender == 2
	
* Remove accounts with lots of duplicates (mainly construction companies)
	keep if type_duplicates!=11 & type_duplicates!=12
	
* Merge with property characteristics 
	merge m:1 nro_cuenta using "${processed_data}/invariant_property_traits.dta", gen(merge_traits)
	
	
* Histogram of residential assessed property values in 2018
	preserve
		keep if residential == 1
		qui sum valuacion_3f if anio == 2018, d
		loc x_p25 = `r(p25)' + 150000
		loc x_p50 = `r(p50)' + 150000
		loc x_p75 = `r(p75)' + 150000
		
		hist valuacion_3f if anio == 2018 & valuacion_3f < `r(p99)', frequency $graphopt legend(off) ///
			 ylabel(0(2000)10000, format(%12.0gc)) yscale(titlegap(3))     							 ///
			 xlabel(, format(%12.0gc)) xscale(titlegap(3)) 						 					 ///
			 xline(`r(p25)', lp(dash) lc(red) lw(thin)) text(10000 `x_p25' "p25", size(vsmall) color(gray%60)) ///
			 xline(`r(p50)', lp(dash) lc(red) lw(thin)) text(10000 `x_p50' "p50", size(vsmall) color(gray%60)) ///
			 xline(`r(p75)', lp(dash) lc(red) lw(thin)) text(10000 `x_p75' "p75", size(vsmall) color(gray%60)) ///
			 xtitle("Assessed value, 2018") ytitle("Frequency") lcolor(gray%40) fcolor(gray%40)
		graph export "${figures}/hist_assessed_value_2018.pdf", replace	
	restore
	
	
* CDF for the assessed property value by gender
	preserve
		keep if residential == 1 & anio == 2018
		drop if missing(female_cuit1)
		
		qui sum valuacion_3f, d
		cdfplot valuacion_3f if valuacion_3f <= `r(p99)', by(owner) $graphopt 		///
				legend(row(3) order(1 "Women" 2 "Men" 3 "Co-Owned") ring(0) pos(5)) ///
				xlabel(, format(%12.0gc)) xlabel(0(1000000)4000000, labsize(small)) /// 
				xscale(titlegap(3)) opt1(lc(dknavy%80 blue%60 ebblue%70) lp(solid longdash -.-) lw(medthick medthick medthick))		
		graph export "${figures}/cdf_assessed_value_gender.pdf", replace
	restore
	
	
* Mean effective tax rates per percentile	
	preserve
		keep if residential == 1
		keep if percentile >= 2 & anio == 2019 
		drop if pago_anual_cuenta_anio == 1
		gcollapse (mean) tasa_efectiva_pago tasa_efectiva_debito, by(percentile)
		
		twoway (scatter tasa_efectiva_pago percentile, c(l) lc(blue%40) mc(blue%40) msymbol(D) msize(small)) ///
			   (scatter tasa_efectiva_debito percentile, c(l) lc(dknavy%80) mc(dknavy%40) msize(small)), 	 ///
			   $graphopt legend(row(2) lab(1 "Empirical ETR") lab(2 "Statutory ETR") ring(0) pos(1))   	     ///
			   yscale(titlegap(3)) ylabel(, format(%12.0gc) angle(0)) xlabel(0(10)100, format(%12.0gc) angle(0)) ///
			   xscale(titlegap(3)) xtitle("Percentiles (assessed value)") subtitle("Mean (%)", placement(7) span)
		graph export "${figures}/effective_tax_rate.pdf", replace
	restore

	
	preserve
		keep if (residential == 1 & anio == 2019)
		drop if pago_anual_cuenta_anio == 1 | missing(owner)
		gcollapse (mean) tasa_efectiva_pago tasa_efectiva_debito, by(owner)
		
		gen dif = tasa_efectiva_debito - tasa_efectiva_pago
		
		qui sum dif if owner == 1
		loc women: di %4.2fc `r(mean)'
		qui sum dif if owner == 2
		loc men: di %4.2fc `r(mean)'
		qui sum dif if owner == 3
		loc co: di %4.2fc `r(mean)'
		
		graph bar tasa_efectiva_debito tasa_efectiva_pago,  over(owner) $graphopt ylabel(0(0.5)1.5, angle(0)) 		///
			  bar(1, color(ebblue%70)) bar(2, color(gray%70)) blabel(bar, pos(outside) color(gray) format(%9.2fc))  ///
			  legend(row(2) order(1 "Statutory ETR" 2 "Empirical ETR") ring(0) pos(1))						    	///
			  subtitle("Average (%)", placement(7) span size(medsmall)) text(1.1 15 "Diff:`women'", color(red)) 	///
			  text(1.1 50 "Diff:`men'", color(red)) text(1.1 85 "Diff:`co'", color(red))
		graph export "${figures}/etr_ownership.pdf", replace
	restore

	
* Probability of paying at least one bill on in the year
	preserve
		keep if residential == 1 & anio == 2019	
		
		sum share_timely, d
		loc avg: di %4.0fc r(mean)
		loc p10: di %4.0fc r(p10)
		loc p50: di %4.0fc r(p50)
		loc p90: di %4.0fc r(p90)
		
		gcollapse (mean) share_timely, by(percentile female_cuit1)
		
		twoway (scatter share_timely percentile if female_cuit1 == 0, c(l) lc(blue%40) mc(blue%40) msymbol(X))      ///
			   (scatter share_timely percentile if female_cuit1 == 1, c(l) lc(dknavy%80) mc(dknavy%50) msymbol(t)), ///
			   yscale(titlegap(0.5)) xscale(titlegap(3)) xlabel(0(10)100, format(%12.0gc))  	 					///
			   xtitle("Percentiles (assessed value)") ytitle("") $graphopt ylabel(0(10)100, angle(0))				///
			   legend(row(2) lab(1 "Men") lab(2 "Women") ring(0) pos(7)) subtitle("Share on-time payments", placement(7) span size(medsmall)) ///
			   text(90 90 "Mean=`avg'%") text(85 90 "P10=`p10'%") text(80 90 "P50=`p50'%") text(75 90 "P90=`p90'%")
		graph export "${figures}/prob_pay.pdf", replace
	restore
	
	
* Probability of taxpayers doing the annual payment in one go 
	preserve
		keep if residential == 1 & anio == 2019
		gcollapse (mean) pago_anual_cuenta_anio, by(decile owner)
		drop if mi(owner)
		reshape wide pago_anual_cuenta_anio, i(decile) j(owner)
		
		twoway (scatter pago_anual_cuenta_anio1 decile, c(l) msymbol(t) lc(dknavyblue%40) mc(dknavy%40)) 	     ///
			   (scatter pago_anual_cuenta_anio2 decile, c(l) msymbol(X) lc(blue%60) mc(blue%60) msize(medlarge)) ///
			   (scatter pago_anual_cuenta_anio3 decile, c(l) msymbol(o) lc(ebblue%70) mc(ebblue%70)),  			 ///
			   $graphopt xtitle("Deciles (assessed value)") ytitle("") xlab(1(1)10) xlabel(, format(%12.0gc))	 ///
			   legend(row(3) lab(1 "Women") lab(2 "Men") lab(3 "Co-Owned") ring(0) pos(1) size(medlarge)) 		 ///
			   yscale(titlegap(3)) ylabel(0(0.05)0.2, format(%12.0gc) angle(0)) xscale(titlegap(3))			 	 ///
			   subtitle("P(Annual payment = 1)", placement(7) span)  
		graph export "${figures}/prob_annual_payment_gender.pdf", replace
	restore
	
	
	
* Composition across type of RESIDENTIAL properties only (apartment, garage, house, house-other)
	preserve
		replace percentile = percentile + 1
		keep if anio == 2018
		egen type = group(type_property)
		gcollapse (count) unit, by(percentile type)
		drop if missing(type)
		reshape wide unit, i(percentile) j(type) 
		
			loc x_labels			
			forvalues j = 1/100 {
				if mod(`j', 10) == 0 | `j' == 1 {
					loc show = `j'
					loc x_labels `x_labels' `j' "`show'"
				}	
				else {
					loc x_labels `x_labels' `j' " "
				}	
			} 
			
		graph bar unit1 unit2 unit3 unit4, 	    											///
		      over(percentile, gap(0) relabel(`x_labels')) 									///
			  percent stack $graphopt ylabel(0(25)100, angle(0)) 							///
			  legend(row(1) lab(1 "Apartment") lab(2 "Garage") 								///
			  lab(3 "Other") lab(4 "Regular")) ytitle("") 									///
			  bar(1, color(ebblue%70) lwidth(none)) bar(2, color(blue%60) lwidth(none))	 	///
			  bar(3, color(cyan%60) lwidth(none)) bar(4, color(dknavy%80) lwidth(none)) 		///
			  b2title("Percentiles (assessed value)", size(medsmall)) subtitle("Share of" "owners (%)", placement(7) span size(medsmall))
		graph export "${figures}/residential_type_percentile.pdf", replace
	restore	

	
* Property ownership by gender
	preserve
		replace percentile = percentile + 1
		keep if residential == 1 & anio == 2018
		gcollapse (count) unit, by(percentile owner)
		drop if missing(owner) | missing(percentile)
		reshape wide unit, i(percentile) j(owner) 
		
		egen total = rowtotal(unit?)
		
		forvalues i = 1/3 {
			gen share_`i' = unit`i' / total
		}
		
		twoway (scatter share_1 percentile, c(l) msymbol(t) lc(dknavyblue%40) mc(dknavy%40)) 	    ///
			   (scatter share_2 percentile, c(l) msymbol(X) lc(blue%40) mc(blue%40) msize(medlarge))  	///
			   (scatter share_3 percentile, c(l) msymbol(o) lc(ebblue%70) mc(ebblue%70)),  ///
			   $graphopt xtitle("Percentiles (assessed value)") ytitle("") xlab(0(10)100) 		///
			   legend(row(3) lab(1 "Women") lab(2 "Men") lab(3 "Co-Owned") ring(0) pos(7) size(medlarge)) ///
			   yscale(titlegap(3)) ylabel(0(0.1)0.6, format(%12.0gc) angle(0))  		    ///
			   xscale(titlegap(3)) xlabel(, format(%12.0gc))					///
			   subtitle("Share (%)", placement(7) span)
		graph export "${figures}/ownership_scatter_gender.pdf", replace
	restore		

	