/*******************************************************************************
Name   : 2c_balance_checks.do

Task   : Create tables with balance checks between treatment and control groups.

Input  : ${raw_data}/working_data_RCT_Oct20.dta
		 ${raw_data}/db_gender.dta
		 
Output : regressions_balance.tex
*******************************************************************************/


*Open RCT payment data
use "${raw_data}/working_data_RCT_Oct20.dta", clear

*Treatment indicator
gen treat=.
replace treat = 0 if treat_123==0 | treat_123==.
replace treat = 1 if treat_123==1
tab treat if periodo==202010

*Merge with data containing gender indicator
merge m:1 nro_cuenta using "${raw_data}/db_gender.dta"

*drop a few accounts with too many properties
*Residential Building Construction administrators
replace treat = . if type_duplicates==11 | type_duplicates==12
tab treat if periodo==202010 & _merge==3


*--------- Prepare some variables
gen lvalue = log(valuacion_3f)

tab categoria if periodo==201912
gen aux = 0 if categoria==2 & periodo==201912
replace aux = 1 if categoria==1 & periodo==201912
egen vivienda = max(aux), by(id)
drop aux

*number of bills paid in 2019
gen aux = pago_cuota_pre if periodo>=201901 & periodo<=201912
egen n_payments_2019=total(aux), by(id)
tab n_payments_2019 if periodo==201912

*Timely payments (up to the 27th of each month)
gen day = day(fpago_are)
gen month = month(fpago_are)
tab day

gen pago_timely=pago_cuota_mismo_mes
replace pago_timely=0 if day>27 & day!=. & month==cuota
*replace pago_timely=. if periodo>202009
tab pago_timely if periodo==202009, m
drop day month

*past-due debt
gen pr_debt = 0
replace pr_debt = 1 if bc>0 & bc!=.

*Control for past compliance
drop aux
local fechas "201801 201802 201803 201804 201805 201806 201807 201808 201809 201810 201811 201812"

foreach ym of local fechas {
  gen aux = pago_cuota_dec20 if periodo==`ym'
  egen pay_`ym' = mean(aux), by(nro_cuenta)
  tab pay_`ym' if periodo==`ym'
  drop aux
}

*balanced panel (37 months)
gen aux = 1 if periodo>=201801 & periodo<=202212
egen balanced = total(aux), by(nro_cuenta)
tab balanced
drop aux

*RCT regression sample
regress pago_timely treat female_cuit1 pay_2018* i.codigo_postal undelivered_letter i.periodo if balanced==37, cluster(num_cuadra)
gen reg_sample=e(sample)
tab reg_sample if balanced==37


**********************************************
** Regression table
**********************************************
*Standard errors clustered by blocks (num_cuadra)

*main result
reg pago_cuota_3oct20 treat if periodo==202010, cluster(num_cuadra)
reg pago_cuota_oct20 treat if periodo==202010, cluster(num_cuadra)


*******************
** Table
*******************
keep if reg_sample==1

gen treat_w = treat if female_cuit1==1
gen treat_m = treat if female_cuit1==0
gen treat_all = treat
*reg pago_cuota_pre treat if periodo==201912, cluster(num_cuadra)

*All
local groups "all w m"
  foreach g of local groups {
  reg lvalue treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg1_`g'
  reg metros_frente treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg2_`g'
  reg vivienda treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg3_`g'
  reg pr_debt treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg4_`g'
  reg monto_pago_pre treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg5_`g'
  reg n_payments_2019 treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg6_`g'
  reg pago_digital treat_`g' if periodo==201912, cluster(num_cuadra)
  estimates store reg7_`g'
}

local options_estout "substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(N, fmt(%9.0fc) labels("Observations")) msign($-$)"

*all
esttab reg1_all reg2_all reg3_all reg4_all reg5_all reg6_all reg7_all using "${tables}/regressions_balance.tex", replace fragment `options_estout' coeflabel(treat_all "\hspace{0.1cm} Treated" _cons "\hspace{0.1cm} Mean Control")  title(Balance tests) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{balance_table}" "\begin{center}" "\begin{threeparttable}" "\begin{adjustbox}{width=\textwidth}" "\begin{tabularx}{\textwidth}{l Y Y Y Y Y Y Y}" "\toprule" "\multicolumn{1}{l}{}&" "\multicolumn{1}{c}{Property}&" "\multicolumn{1}{c}{Front}&" "\multicolumn{1}{c}{House}&" "\multicolumn{1}{c}{Past due}&" "\multicolumn{1}{c}{Bill}&" "\multicolumn{1}{c}{N Bills}&" "\multicolumn{1}{c}{Digital}\\" "\multicolumn{1}{l}{}&" "\multicolumn{1}{c}{Value}&" "\multicolumn{1}{c}{meters}&" "\multicolumn{1}{c}{type}&" "\multicolumn{1}{c}{debt}&" "\multicolumn{1}{c}{amount}&" "\multicolumn{1}{c}{paid 2019}&" "\multicolumn{1}{c}{payment}\\" "\cline{2-8}") posthead("\midrule \multicolumn{8}{l}{\emph{\textbf{A. Women and Men}}} \\")
eststo clear

*women (append)
esttab reg1_w reg2_w reg3_w reg4_w reg5_w reg6_w reg7_w using "${tables}/regressions_balance.tex", append fragment `options_estout' coeflabel(treat_w "\hspace{0.1cm} Treated" _cons "\hspace{0.1cm} Mean Control") posthead("\midrule \multicolumn{8}{l}{\emph{\textbf{B. Women}}} \\") nomtitles nonumbers
eststo clear

*men (append)
esttab reg1_m reg2_m reg3_m reg4_m reg5_m reg6_m reg7_m using "${tables}/regressions_balance.tex", append fragment `options_estout' coeflabel(treat_m "\hspace{0.1cm} Treated" _cons "\hspace{0.1cm} Mean Control") posthead("\midrule \multicolumn{8}{l}{\emph{\textbf{C. Men}}} \\") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\end{adjustbox}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table shows balance regressions to test for differences in observable characteristics between the treatment and control groups. Each column corresponds to a separate regression (equation (\ref{eqn:saturated_balance}) in the text). The dependent variables in each column are: (1) the log of assessed property value; (2) the front meters of the property; (3) an indicator for the property being a house versus a house with a store; (4) an indicator for past due debt; (5) the amount paid in the bill corresponding to December 2019 (including zeroes); (6) the number of bills paid in 2019 (the maximum is 12); (7) for those who paid, whether they did so digitally. The rows \emph{Mean Control} display the constant of each regression, corresponding to the average of the dependent variable for accounts that did not receive a letter. Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table}) nomtitles nonumbers booktabs


