/*******************************************************************************
Name   : 2d_analysis_RCT.do

Task   : Main analysis from RCT.

Input  : ${raw_data}/working_data_RCT_Oct20.dta
		 ${raw_data}/db_gender.dta
		 
Output : Level-probpay-timely-control.pdf
		 Level-probpay-control.pdf
		 DinD-probpay-gender.pdf
		 DinD-probpay-timely-gender.pdf
		 DinD-probpay-timely-gender-quintiles.pdf
		 Level-probpay-timely-control-quintiles.pdf
		 DinD-probpay-timely-gender-quintiles-placebo.pdf
		 Level-probpay-timely-control-quintiles-placebo.pdf
		 regressions_timely_payments.tex
*******************************************************************************/

*Open RCT payment data
use "${raw_data}/working_data_RCT_Oct20.dta", clear

*Treatment indicator
gen treat=.
replace treat = 0 if treat_123==0 | treat_123==.
replace treat = 1 if treat_123==1
tab treat if periodo==202010

*Merge with data containing gender indicator
merge m:1 nro_cuenta using "${raw_data}/db_gender.dta"

*drop a few accounts with too many properties
*Residential Building Construction administrators
replace treat = . if type_duplicates==11 | type_duplicates==12
tab treat if periodo==202010 & _merge==3

*quickly test the average effect
reg pago_cuota_dec20 treat if periodo==202010
reg pago_cuota_dec20 treat if periodo==202010 & _merge==3
reg pago_cuota_pre treat if periodo==202008 & _merge==3
*gender sample
reg pago_cuota_dec20 treat if periodo==202010 & _merge==3 & female_cuit1!=.
reg pago_cuota_dec20 treat if periodo==202010 & _merge==3 & female_cuit1==1
reg pago_cuota_dec20 treat if periodo==202010 & _merge==3 & female_cuit1==0

*interaction term for the DiD
gen inter = treat*female_cuit1
reg pago_cuota_dec20 treat female_cuit1 inter if periodo==202010 & _merge==3


**********************************************
** Prep before regressions
**********************************************
local dates "201901 201902 201903 201904 201905 201906 201907 201908 201909 201910 201911 201912 202001 202002 202003 202004 202005 202006 202007 202008 202009 202010 202011 202012"
local dates_pre "201901 201902 201903 201904 201905 201906 201907 201908 201909 201910 201911 201912 202001 202002 202003 202004 202005 202006 202007 202008 202009"


tab pago_cuota_mismo_mes if periodo==202010
tab fpago_are if periodo==202010 & pago_cuota_mismo_mes==1

*Timely payments (up to the 27th of each month)
gen day = day(fpago_are)
gen month = month(fpago_are)
tab day

gen pago_timely=pago_cuota_mismo_mes
replace pago_timely=0 if day>27 & day!=. & month==cuota
*replace pago_timely=. if periodo>202009
tab pago_timely if periodo==202009, m
drop day month


*Control for past compliance
local fechas "201801 201802 201803 201804 201805 201806 201807 201808 201809 201810 201811 201812"

foreach ym of local fechas {
  gen aux = pago_cuota_dec20 if periodo==`ym'
  egen pay_`ym' = mean(aux), by(nro_cuenta)
  tab pay_`ym' if periodo==`ym'
  drop aux
}

*- COMPLIANCE IN 2018 (for heterogeneity analysis)

*Share of the 12 cuotas paid in 2018
gen aux2018 = pago_cuota_dec20 if anio==2018
egen share_indiv_2018 = mean(aux2018), by(nro_cuenta)
*N cuotas paid in 2018
egen N_indiv_2018 = total(aux2018), by(nro_cuenta)
drop aux2018

tab N_indiv_2018 if periodo==202010

*never/always payers
gen neverpayer_18 = N_indiv_2018==0
gen alwayspayer_18 = N_indiv_2018==12

*balanced panel (37 months)
gen aux = 1 if periodo>=201801 & periodo<=202212
egen balanced = total(aux), by(nro_cuenta)
tab balanced
drop aux

*regression sample
regress pago_timely treat female_cuit1 pay_2018* i.codigo_postal undelivered_letter i.periodo, cluster(num_cuadra)
gen reg_sample=e(sample)
tab reg_sample if balanced==37


*preserve
*drop if female_cuit2!=.
*gen coowned = female_cuit1!=. & female_cuit2!=.

********************************************
*** LEVELS - control group
********************************************
mat A1 = J(1,9,.)
foreach ym of local dates {
  display in red " -------> Period -------> `ym'"
  
  *Women
  *Prob timely payments
  regress pago_timely treat if periodo==`ym' & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  mat bT1=(_b[_cons]+_b[treat])*100
  mat bC1=_b[_cons]*100
  
  *Prob timely and pastdue payments
  regress pago_cuota_dec20 treat if periodo==`ym' & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  mat bT11=(_b[_cons]+_b[treat])*100
  mat bC11=_b[_cons]*100
  
  *Men
  *Prob timely payments
  regress pago_timely treat if periodo==`ym' & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  mat bT0=(_b[_cons]+_b[treat])*100
  mat bC0=_b[_cons]*100
  
  *Prob timely and pastdue payments
  regress pago_cuota_dec20 treat if periodo==`ym' & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  mat bT00=(_b[_cons]+_b[treat])*100
  mat bC00=_b[_cons]*100
  
  mat A1=A1\(`ym',bT1,bC1,bT0,bC0,bT11,bC11,bT00,bC00)
  
}
mat colnames A1 = "period" "bT_w" "bC_w" "bT_m" "bC_m" "bTall_w" "bCall_w" "bTall_m" "bCall_m"
svmat A1, names(col)

gen aniocuota = ym(floor(period/100), mod(period, 100))
format aniocuota %tm
gen aniocuota_aux=aniocuota+.25

**Control: timely payments
twoway (connected bC_w bC_m aniocuota, msy(O t) mcol(maroon*.3 navy*.3) lcol(maroon*.3 navy*.3) mlcol(maroon navy)) (pcarrowi 60 722.6 60 725, lcol(gray) mcolor(gray)), $bgopt xlabel(#10,angle(0)) ylab(0(10)65, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Billing Period") xline(722.5 729, lpat(dot) lcol(black)) text(55 725 "COVID-19" "billing periods", color(gray)) text(65 729 "{bf:Treated bill}" "Oct'20", color(gray)) xsize(6) legend(order(1 "Control (women)" 2 "Control (men)") ring(0) pos(9) col(1) region(style(none)) size(large))
graph export "${figures}/Level-probpay-timely-control.pdf", replace 

**Control: timely + pastdue payments
twoway (connected bCall_w bCall_m aniocuota, msy(O t) mcol(maroon*.3 navy*.3) lcol(maroon*.3 navy*.3) mlcol(maroon navy)) (pcarrowi 60 722.6 60 725, lcol(gray) mcolor(gray)), $bgopt xlabel(#10,angle(0)) ylab(0(10)65, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Billing Period") xline(722.5 729, lpat(dot) lcol(black)) text(55 725 "COVID-19" "billing periods", color(gray)) text(65 729 "{bf:Treated bill}" "Oct'20", color(gray)) xsize(6) legend(order(1 "Control (women)" 2 "Control (men)") ring(0) pos(9) col(1) region(style(none)) size(large))
graph export "${figures}/Level-probpay-control.pdf", replace 


********************************************
*** MEAN DIFF --> T vs C
********************************************

********************************************
*** Pre-intervention payments (benchmark)
********************************************

mat A1 = J(1,3,.)
mat M1 = J(1,3,.)
foreach ym of local dates_pre {
  display in red " -------> Period -------> `ym'"

  *Women
  regress pago_cuota_pre treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b3=A[1,1]*100
  mat ll3=A[5,1]*100
  mat ul3=A[6,1]*100
  
  mat A1=A1\(b3,ll3,ul3)

  *Men
  regress pago_cuota_pre treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b3=A[1,1]*100
  mat ll3=A[5,1]*100
  mat ul3=A[6,1]*100
  
  mat M1=M1\(b3,ll3,ul3)
}

mat colnames A1 = "dd_old_w" "dd_ll_old_w" "dd_ul_old_w" 
svmat A1, names(col)
mat colnames M1 = "dd_old_m" "dd_ll_old_m" "dd_ul_old_m" 
svmat M1, names(col)


********************************************
*** Prob timely payments
********************************************
mat A1 = J(1,4,.)
mat M1 = J(1,4,.)
foreach ym of local dates {
  display in red " -------> Period -------> `ym'"
  
  *Women
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat A1=A1\(b,se,ll,ul)

  *Men
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat M1=M1\(b,se,ll,ul)
}
mat colnames A1 = "dd_w" "se_w" "dd_ll_w" "dd_ul_w"
svmat A1, names(col)
mat colnames M1 = "dd_m" "se_m" "dd_ll_m" "dd_ul_m"
svmat M1, names(col)


********************************************
*** Prob paying (includes late payments)
********************************************
mat A1 = J(1,4,.)
mat M1 = J(1,4,.)
foreach ym of local dates {
  display in red " -------> Period -------> `ym'"

  regress pago_cuota_dec20 treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat A1=A1\(b,se,ll,ul)

  regress pago_cuota_dec20 treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==`ym' & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat M1=M1\(b,se,ll,ul)
}

mat colnames A1 = "dd_women" "se_women" "dd_ll_women" "dd_ul_women"
mat colnames M1 = "dd_men" "se_men" "dd_ll_men" "dd_ul_men"
svmat A1, names(col)
svmat M1, names(col)



*DD estimate (timely and past-due payments)
twoway (rspike dd_ll_women dd_ul_women aniocuota, sort color(maroon%30) msize(*.5)) (connected dd_women aniocuota, msy(O)  msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rspike dd_ll_men dd_ul_men aniocuota_aux, sort color(navy%30) msize(*.5)) (connected dd_men aniocuota_aux, msy(T)  msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)) (pcarrowi 5.2 722.6 5.2 725, lcol(gray) mcolor(gray)), $bgopt xlabel(#10, angle(0)) ylab(-3(1)7,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Billing Period") yline(0, lcol(black)) xsize(6) text(4.5 730.5 "3.9 p.p.", size(medsmall)) text(6 725 "COVID-19" "billing periods", color(gray)) text(7.5 729 "{bf:Treated bill}" "Oct'20", color(gray)) xline(722.5 728.7, lpat(dot) lcol(black)) legend(order(2 "Women" 4 "Men") ring(0) pos(11) region(style(none)) col(1) size(large))
graph export "${figures}/DinD-probpay-gender.pdf", replace 

*DD estimate (timely payments)
twoway (rspike dd_ll_w dd_ul_w aniocuota, sort color(maroon%30) msize(*.5)) (connected dd_w aniocuota, msy(O) msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rspike dd_ll_m dd_ul_m aniocuota_aux, sort color(navy%30) msize(*.5)) (connected dd_m aniocuota_aux, msy(T) msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)) (pcarrowi 5.2 722.6 5.2 725, lcol(gray) mcolor(gray)), $bgopt xlabel(#10, angle(0)) ylab(-3(1)7,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Billing Period") yline(0, lcol(black)) xsize(6) text(5 730.5 "4.7 p.p.", size(medsmall)) text(6 725 "COVID-19" "billing periods", color(gray)) text(7.5 729 "{bf:Treated bill}" "Oct'20", color(gray)) xline(722.5 728.7, lpat(dot) lcol(black)) legend(order(2 "Women" 4 "Men") ring(0) pos(11) region(style(none)) col(1) size(large))
graph export "${figures}/DinD-probpay-timely-gender.pdf", replace 



********************************************
*** QUINTILES: Prob timely payments 
********************************************
xtile aux = valuacion_3f if periodo==202010 &  balanced==37 & reg_sample==1, nquantiles(5)
egen quintiles = max(aux), by(nro_cuenta)
drop aux

*Average effect = 4.5 p.p.
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202010 & balanced==37 & reg_sample==1, cluster(num_cuadra)

mat A1 = J(1,4,.)
mat M1 = J(1,3,.)
forv d=1(1)5 {
  display in red " -------> Fractile -------> `d'"
  
  *Women
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202010 & female_cuit1==1 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat A1=A1\(`d',b,ll,ul)

  *Men
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202010 & female_cuit1==0 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat M1=M1\(b,ll,ul)
}
mat colnames A1 = "frac" "dg_w" "ll_w" "ul_w"
svmat A1, names(col)
mat colnames M1 = "dg_m" "ll_m" "ul_m"
svmat M1, names(col)
gen frac_aux=frac+.1


*DD estimate (timely payments)
twoway (rcap ll_w ul_w frac, sort color(maroon%30) msize(*.5)) (connected dg_w frac, msy(O) msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rcap ll_m ul_m frac_aux, sort color(navy%30) msize(*.5)) (connected dg_m frac_aux, msy(T) msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)), $bgopt xlabel(0.7 " " 1 2 3 4 5 5.3 " ", angle(0)) ylab(-1(1)10,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Quintiles (assessed value)") yline(0, lcol(black)) yline(4.5, lcol(black) lpat(dot)) xsize(6) legend(order(2 "Women" 4 "Men") ring(0) pos(1) region(style(none)) col(1) size(large)) text(4.9 1.3 "Avg Effect = 4.5 p.p.", color(gray))
graph export "${figures}/DinD-probpay-timely-gender-quintiles.pdf", replace 



****************************
*** LEVELS - control group
****************************
mat A1 = J(1,2,.)
forv d=1(1)5 {
  display in red " -------> Fractile -------> `d'"
  
  *Women
  regress pago_timely treat if periodo==202010 & female_cuit1==1 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  mat bC1=_b[_cons]*100
  
  *Men
  regress pago_timely treat if periodo==202010 & female_cuit1==0 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  mat bC0=_b[_cons]*100
  
  mat A1=A1\(bC1,bC0)
  
}
mat colnames A1 = "dC_w" "dC_m"
svmat A1, names(col)


**Control: timely payments
twoway (connected dC_w dC_m frac, msy(O t) msize(vlarge vlarge) mcol(maroon*.3 navy*.3) lcol(maroon*.3 navy*.3) mlcol(maroon navy)), $bgopt xlabel(0.7 " " 1 2 3 4 5 5.3 " ") ylab(0(10)65, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Quintiles (assessed value)") xsize(6) legend(order(1 "Control (women)" 2 "Control (men)") ring(0) pos(1) col(1) region(style(none)) size(large)) text(23 1 "27%", color(navy) size(large)) text(35 1 "29%", color(maroon) size(large)) text(33 5 "38%", color(navy) size(large)) text(45 5 "40%", color(maroon) size(large))
graph export "${figures}/Level-probpay-timely-control-quintiles.pdf", replace 


****************************
*** PLACEBO - Sept'20 bill
****************************

*Average effect = 0.0005 p.p.
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202009 & balanced==37 & reg_sample==1, cluster(num_cuadra)

drop frac - dC_m

mat A1 = J(1,4,.)
mat M1 = J(1,3,.)
forv d=1(1)5 {
  display in red " -------> Fractile -------> `d'"
  
  *Women
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202009 & female_cuit1==1 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat A1=A1\(`d',b,ll,ul)

  *Men
  regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202009 & female_cuit1==0 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  matrix A=r(table)
  mat b=A[1,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat M1=M1\(b,ll,ul)
}
mat colnames A1 = "frac" "dg_w" "ll_w" "ul_w"
svmat A1, names(col)
mat colnames M1 = "dg_m" "ll_m" "ul_m"
svmat M1, names(col)
gen frac_aux=frac+.1


*DD estimate (timely payments)
twoway (rcap ll_w ul_w frac, sort color(maroon%30) msize(*.5)) (connected dg_w frac, msy(O) msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rcap ll_m ul_m frac_aux, sort color(navy%30) msize(*.5)) (connected dg_m frac_aux, msy(T) msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)), $bgopt xlabel(0.7 " " 1 2 3 4 5 5.3 " ", angle(0)) ylab(-5(1)6,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Quintiles (assessed value)") yline(0, lcol(black)) xsize(6) legend(order(2 "Women" 4 "Men") ring(0) pos(1) region(style(none)) col(1) size(large))
graph export "${figures}/DinD-probpay-timely-gender-quintiles-placebo.pdf", replace 


** LEVELS - control group
mat A1 = J(1,2,.)
forv d=1(1)5 {
  display in red " -------> Fractile -------> `d'"
  
  *Women
  regress pago_timely treat if periodo==202009 & female_cuit1==1 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  mat bC1=_b[_cons]*100
  
  *Men
  regress pago_timely treat if periodo==202009 & female_cuit1==0 & balanced==37 & reg_sample==1 & quintiles==`d', cluster(num_cuadra)
  mat bC0=_b[_cons]*100
  
  mat A1=A1\(bC1,bC0)
  
}
mat colnames A1 = "dC_w" "dC_m"
svmat A1, names(col)


**Control: timely payments
twoway (connected dC_w dC_m frac, msy(O t) msize(vlarge vlarge) mcol(maroon*.3 navy*.3) lcol(maroon*.3 navy*.3) mlcol(maroon navy)), $bgopt xlabel(0.7 " " 1 2 3 4 5 5.3 " ") ylab(0(10)65, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Quintiles (assessed value)") xsize(6) legend(order(1 "Control (women)" 2 "Control (men)") ring(0) pos(1) col(1) region(style(none)) size(large))
graph export "${figures}/Level-probpay-timely-control-quintiles-placebo.pdf", replace 


/*
Effect in October for T=1,2,3:
Scale the effect relative to the control group
.0529127/.3934927
.0342907/.4015241
.0336667/.4038618
*/


*************************************************
** TABLE
*************************************************

replace pago_timely=pago_timely*100

** Placebo: Sep'20 **
*Women
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202009 & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
estimates store reg1
qui sum `e(depvar)' if e(sample) & treat==0
estadd scalar Mean= r(mean)

*Men
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202009 & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
estimates store reg2
qui sum `e(depvar)' if e(sample) & treat==0
estadd scalar Mean= r(mean)

** Intervention: Oct'20 **
*Women
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202010 & female_cuit1==1 & balanced==37 & reg_sample==1, cluster(num_cuadra)
estimates store reg3
qui sum `e(depvar)' if e(sample) & treat==0
estadd scalar Mean= r(mean)

*Men
regress pago_timely treat pay_2018* i.codigo_postal undelivered_letter neverpayer_18 if periodo==202010 & female_cuit1==0 & balanced==37 & reg_sample==1, cluster(num_cuadra)
estimates store reg4
qui sum `e(depvar)' if e(sample) & treat==0
estadd scalar Mean= r(mean)


local options_estout "coeflabel(treat "\hspace{0.1cm} Treated") order(treat) substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(Mean N N_clust, fmt(2 %9.0fc) labels("Control mean" "Observations" "Number of clusters (blocks) \hspace{4cm}")) drop(pay_2018* *.codigo_postal undelivered_letter neverpayer_18 _cons) replace"

esttab reg1 reg2 reg3 reg4 using "${tables}/regressions_timely_payments.tex", `options_estout' booktabs title(Treatment effects on property tax payments for women and men) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{main_table}" "\begin{center}" "\begin{threeparttable}" "\setlength{\tabcolsep}{20pt}" "\begin{tabularx}{\textwidth}{l*{4}{c}}" "\toprule" "\multicolumn{1}{l}{\textbf{Dependent variable:}}&" "\multicolumn{2}{c}{\textbf{Placebo bill} (Sept'20)}&" "\multicolumn{2}{c}{\textbf{Intervention bill} (Oct'20)}\\" "\multicolumn{1}{l}{Pr(pay the bill)}&" "\multicolumn{1}{c}{Women}&" "\multicolumn{1}{c}{Men}&" "\multicolumn{1}{c}{Women}&" "\multicolumn{1}{c}{Men}\\" "\cmidrule(l){2-3}" "\cmidrule(l){4-5}") posthead("\midrule") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table summarizes the treatment effects of the randomized tax communication campaign on property tax payments for men and women. Each column corresponds to a separate regression. The dependent variable is an indicator for paying the bill on time. Timely payments are defined as bills paid before the 27th of the corresponding month (i.e., any payment made after the 27th is coded as unpaid). Columns 1 and 2 correspond to the pre-intervention bill of September 2020; Columns 1 and 2 correspond to the October 2020 intervention bill. The estimates match those shown in Figure (\ref{figure:DID-bills}). The letters were delivered between September 28th and October 7th. The due date for the October 2020 bill was October 9th. The row \emph{Control mean} displays the average payment rate for untreated units who received no letter. These regressions control for tax compliance in 2018, zip codes fixed effects, an indicator for undelivered letters, and an indicator for those paying no bills in 2018. Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table})


