/*******************************************************************************
Name   : 2e_analysis_cuota10.do

Task   : Analysis of billion period October 2020

Input  : ${raw_data}/working_data_RCT_Oct20.dta
		 ${raw_data}/db_gender.dta
		 
Output : payments-density-Oct20.pdf
		 payment-rate-diff-Oct20-gender.pdf
		 payments-density-Jul20.pdf
		 payment-rate-diff-Jul20-gender.pdf
*******************************************************************************/

*Open RCT payment data
use "${raw_data}/working_data_RCT_Oct20.dta", clear

*Treatment indicator
gen treat=.
replace treat = 0 if treat_123==0 | treat_123==.
replace treat = 1 if treat_123==1
tab treat if periodo==202010

*Merge with data containing gender indicator
merge m:1 nro_cuenta using "${raw_data}/db_gender.dta"

*drop a few accounts with too many properties
*Residential Building Construction administrators
replace treat = . if type_duplicates==11 | type_duplicates==12
tab treat if periodo==202010 & _merge==3


**********************************************
** Prep before regressions
**********************************************

*Timely payments (up to the 27th of each month)
gen day = day(fpago_are)
gen month = month(fpago_are)
tab day

gen pago_timely=pago_cuota_mismo_mes
replace pago_timely=0 if day>27 & day!=. & month==cuota
*replace pago_timely=. if periodo>202009
tab pago_timely if periodo==202009, m
drop day month

*Control for past compliance
local fechas "201801 201802 201803 201804 201805 201806 201807 201808 201809 201810 201811 201812"

foreach ym of local fechas {
  gen aux = pago_cuota_pre if periodo==`ym'
  egen pay_`ym' = mean(aux), by(nro_cuenta)
  tab pay_`ym' if periodo==`ym'
  drop aux
}

*Share of the 12 cuotas paid in 2018
gen aux2018 = pago_cuota_pre if anio==2018
egen share_indiv_2018 = mean(aux2018), by(nro_cuenta)
*N cuotas paid in 2018
egen N_indiv_2018 = total(aux2018), by(nro_cuenta)
drop aux2018
tab N_indiv_2018 if periodo==202010

*never/always payers
gen neverpayer_18 = N_indiv_2018==0
gen alwayspayer_18 = N_indiv_2018==12

*balanced panel (37 months)
gen aux = 1 if periodo>=201801 & periodo<=202212
egen balanced = total(aux), by(nro_cuenta)
tab balanced
drop aux

*regression sample
regress pago_cuota_dec20 treat female_cuit1 pay_2018* i.codigo_postal undelivered_letter i.periodo, cluster(num_cuadra)
gen reg_sample=e(sample)
tab reg_sample if balanced==37


***************************
** October 2020 - Cuota 10
***************************

**Distribution of payment date for men and women
tab fvto if periodo==202010 & reg_sample==1 & balanced==37
dis mdy(10,9,2020)
twoway (histogram fpago_are if periodo==202010 & reg_sample==1 & balanced==37 & fpago_are>mdy(9,25,2020) & fpago_are<=mdy(12,31,2020) & female_cuit1==0, color(navy%30) discrete frac) (histogram fpago_are if periodo==202010 & reg_sample==1 & balanced==37 & fpago_are>mdy(9,25,2020) & fpago_are<=mdy(12,31,2020) & female_cuit1==1, color(maroon%30) discrete frac), xline(22197.5, lpat(dash) lcol(gray)) $bgopt legend(order(2 "Women" 1 "Men" ) ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(,angle(0) nogrid) xlab(#7) text(.14 22205 "{bf:Due date}" "{bf:Oct'20 bill}", color(gray)) subtitle("Fraction", placement(7) span) ytitle("") xsize(6)
graph export "${figures}/payments-density-Oct20.pdf", replace 


**Rectangularize dataset 
*(to obtain a balanced daily panel)
preserve

keep if periodo==202010 & reg_sample==1 & balanced==37

keep id fpago_are pago_cuota treat num_cuadra female_cuit1 pay_2018* neverpayer_18 undelivered_letter
fillin id fpago_are

*payment dummy (=1 after people paid the October 2020 bill)
sort id fpago_are
bys id: gen paid_bill = sum( pago_cuota )

*expand num_cuadra
sort id num_cuadra
by id : replace num_cuadra = num_cuadra[1]
sort id fpago_are

*expand T/C status
foreach var of varlist pay_2018* neverpayer_18 undelivered_letter treat female_cuit1 {
  egen d`var'=max(`var'), by(id)
}

*keep relevant subperiod
*keep if ( fpago_are>=mdy(6,5,2020) & fpago_are<=mdy(12,31,2020) )
keep if ( fpago_are>=mdy(9,25,2020) & fpago_are<=mdy(10,31,2020) )

*unit fixed effect
gen aux = _n if fpago_are==mdy(9,25,2020)
egen idi = max(aux), by(id)
drop aux

tab fpago_are, gen(_T)

*Saturated regression: day by day

foreach var of varlist _T1-_T37 {
  gen dtreat`var' = `var'*dtreat
}

*women
reg paid_bill dtreat_T1-dtreat_T37 _T1-_T37  dpay_2018* dneverpayer_18 dundelivered_letter if dfemale_cuit1==1, cluster(id) nocons
matrix A = r(table)
matrix T1 = ( (A[1,1..37])' , (A[5,1..37])' , (A[6,1..37])' ) * 100

*men
reg paid_bill dtreat_T1-dtreat_T37 _T1-_T37  dpay_2018* dneverpayer_18 dundelivered_letter if dfemale_cuit1==0, cluster(id) nocons
matrix B = r(table)
matrix T2 = ( (B[1,1..37])' , (B[5,1..37])' , (B[6,1..37])' ) * 100

matrix R = T1,T2
svmat R
gen xvar = _n+22182 if _n<=37
format xvar %td
gen xvar2=xvar+0.3


**women vs men
twoway (rspike R2 R3 xvar, sort color(maroon%30) msize(*.5)) (connected R1 xvar, msy(O)  msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rspike R5 R6 xvar2, sort color(navy%30) msize(*.5)) (connected R4 xvar2, msy(T)  msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)), $bgopt xlabel(22183(7)22219) ylab(-2(1)7, angle(0) nogrid) ytit(" ") subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Calendar date") yline(0, lcol(black)) legend(off) xline(22186 22197, lpat(dash) lcol(gray)) name(g3, replace) text(6.8 22186 "{bf:Intervention}" "{bf:begins}", size(medsmall) color(gray)) text(7 22194 "{bf:Due date}" "{bf:Oct'20 bill}", color(gray)) xsize(6) text(7 22210 "{bf:Men}", color(navy) size(vlarge)) text(2 22210 "{bf:Women}", color(maroon) size(vlarge))
graph export "${figures}/payment-rate-diff-Oct20-gender.pdf", replace 

restore



***************************
** July 2020 - Cuota 7
***************************

**Distribution of payment date for men and women
tab fvto if periodo==202007 & reg_sample==1 & balanced==37
dis mdy(7,8,2020)
twoway (histogram fpago_are if periodo==202007 & reg_sample==1 & balanced==37 & fpago_are>mdy(6,25,2020) & fpago_are<=mdy(12,31,2020) & female_cuit1==0, color(navy%30) discrete frac) (histogram fpago_are if periodo==202007 & reg_sample==1 & balanced==37 & fpago_are>mdy(6,25,2020) & fpago_are<=mdy(12,31,2020) & female_cuit1==1, color(maroon%30) discrete frac), xline(22104.5, lpat(dash) lcol(gray)) $bgopt legend(order(2 "Women" 1 "Men" ) ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(,angle(0) nogrid) xlab(#7) text(.19 22120 "{bf:Due date}" "{bf:July '20 bill}", color(gray)) subtitle("Fraction", placement(7) span) ytitle("") xsize(6)
graph export "${figures}/payments-density-Jul20.pdf", replace 


**Rectangularize dataset 
*(to obtain a balanced daily panel)
preserve

keep if periodo==202007 & reg_sample==1 & balanced==37

keep id fpago_are pago_cuota treat num_cuadra female_cuit1 pay_2018* neverpayer_18 undelivered_letter
fillin id fpago_are

*payment dummy (=1 after people paid the July 2020 bill)
sort id fpago_are
bys id: gen paid_bill = sum( pago_cuota )

*expand num_cuadra
sort id num_cuadra
by id : replace num_cuadra = num_cuadra[1]
sort id fpago_are

*expand T/C status
foreach var of varlist pay_2018* neverpayer_18 undelivered_letter treat female_cuit1 {
  egen d`var'=max(`var'), by(id)
}

*keep relevant subperiod
keep if ( fpago_are>=mdy(6,30,2020) & fpago_are<=mdy(7,31,2020) )

*unit fixed effect
gen aux = _n if fpago_are==mdy(8,31,2020)
egen idi = max(aux), by(id)
drop aux

tab fpago_are, gen(_T)

*Saturated regression: day by day

foreach var of varlist _T1-_T32 {
  gen dtreat`var' = `var'*dtreat
}

*women
reg paid_bill dtreat_T1-dtreat_T32 _T1-_T32 dpay_2018* dneverpayer_18 dundelivered_letter if dfemale_cuit1==1, cluster(id) nocons
matrix A = r(table)
matrix T1 = ( (A[1,1..32])' , (A[5,1..32])' , (A[6,1..32])' ) * 100

*men
reg paid_bill dtreat_T1-dtreat_T32 _T1-_T32 dpay_2018* dneverpayer_18 dundelivered_letter if dfemale_cuit1==0, cluster(id) nocons
matrix B = r(table)
matrix T2 = ( (B[1,1..32])' , (B[5,1..32])' , (B[6,1..32])' ) * 100

matrix R = T1,T2
svmat R
di mdy(6,30,2020)
gen xvar = _n+22095 if _n<=32
format xvar %td
gen xvar2=xvar+0.3


**women vs men
twoway (rspike R2 R3 xvar, sort color(maroon%30) msize(*.5)) (connected R1 xvar, msy(O)  msize(medlarge) mcol(maroon*.3) lcol(maroon*.3) mlcol(maroon)) (rspike R5 R6 xvar2, sort color(navy%30) msize(*.5)) (connected R4 xvar2, msy(T)  msize(medlarge) mcol(navy*.3) lcol(navy*.3) mlcol(navy)), $bgopt xlabel(22096(5)22127) ylab(-2(1)7, angle(0) nogrid) ytit(" ") subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Calendar date") yline(0, lcol(black)) legend(off) xline(22104, lpat(dash) lcol(gray)) name(g3, replace) text(7 22101.5 "{bf:Due date}" "{bf:Jul'20 bill}", color(gray)) xsize(6) text(2 22120 "{bf:Men}", color(navy) size(vlarge)) text(-2 22120 "{bf:Women}", color(maroon) size(vlarge))
graph export "${figures}/payment-rate-diff-Jul20-gender.pdf", replace 

restore

